@@ -2,7 +2,7 @@ from typing import List, Optional
 
 from camel_model.camel_model import CamelModel
 
-from domain.distribution.distribution_image import DistributionImage
+from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 
 
 class DataBlock(CamelModel):
